@@ -4,7 +4,7 @@ from dagster import InputDefinition, Nothing, OutputDefinition
 from qdk.base import BaseComponent
 
 
-class BaseLoaderComponent(BaseComponent):
+class BaseLoader(BaseComponent):
     compute_function = "load"
     tags = {
         "kind": "loader",
