@@ -4,11 +4,11 @@ import dask.dataframe as dd
 import pandas as pd
 from dagster import Field, Noneable, OutputDefinition, Permissive
 from qdk.dagster_types import DataFrameType
-from qdk.loader.base import BaseLoaderComponent
+from qdk.loader.base import BaseLoader
 from qdk.s3_connection import S3Connection
 
 
-class DataFrameLoader(BaseLoaderComponent):
+class DataFrameLoader(BaseLoader):
     output_defs = [
         OutputDefinition(DataFrameType, "df"),
     ]
