@@ -1,21 +1,16 @@
-from dagster import (
-    DagsterType,
-    ModeDefinition,
-    PipelineExecutionResult,
-    SolidDefinition,
-    execute_pipeline,
-    pipeline,
-)
+from dagster import ModeDefinition, PipelineExecutionResult, execute_pipeline, pipeline
 from dagster.core.execution.results import SolidExecutionResult
 from dask.dataframe import DataFrame as DaskDataFrame
 from pandas import DataFrame
-from qdk import DataFrameLoader, YakeComponent, qdk_io_manager
+from qdk import DataFrameLoader, YakeTransformer, qdk_io_manager
 
 from ..utils.dataframe import CSVStoreDataFrame
 
-loader_solid = DataFrameLoader.to_solid(name="loader")
+loader_solid = DataFrameLoader.to_solid(
+    name="loader",
+)
 
-keyword_solid = YakeComponent.to_solid(
+keyword_solid = YakeTransformer.to_solid(
     name="keyword",
 )
 
@@ -43,7 +38,10 @@ def run_pipeline(tmpdir: str, use_dask: bool) -> SolidExecutionResult:
                     }
                 },
                 "keyword": {
-                    "config": {"language": "en", "text_columns": ["description"]}
+                    "config": {
+                        "language": "en",
+                        "text_columns": ["description"],
+                    },
                 },
             }
         },
