@@ -1,17 +1,20 @@
-import pandas as pd
+from typing import Any, Dict, Union
+
 import dask.dataframe as dd
+import pandas as pd
 from dagster import Field, OutputDefinition, Permissive
 from qdk.dagster_types import MLFlowRunType
-from qdk.training.base import TrainingComponent
 from qdk.mlflow import MLFlowRun
-from typing import Any, Dict, Union
+from qdk.training.base import BaseTrainer
+
+from mlflow import autolog, set_experiment, sklearn, start_run, xgboost
 from sklearn.base import BaseEstimator
-from mlflow import set_experiment, autolog, start_run, xgboost, sklearn
 
 
-class MLFlowTrainingComponent(TrainingComponent):
-    # required_resource_keys = {"mlflow"}
-    output_defs = [OutputDefinition(MLFlowRunType, "mlflow_run")]
+class MLFlowTrainer(BaseTrainer):
+    output_defs = [
+        OutputDefinition(MLFlowRunType, "mlflow_run"),
+    ]
     config_schema = {
         "experiment_name": Field(
             str,
