@@ -1,17 +1,15 @@
 import multiprocessing
-from typing import Optional, Tuple, Union
+from typing import Union
 
 import dask.dataframe as dd
 import pandas as pd
 from dagster import Field, InputDefinition, OutputDefinition
 from gensim.models.word2vec import Word2Vec
 from qdk.dagster_types import DataFrameType, ModelType
-from qdk.training.base import TrainingComponent
-
-from sklearn.base import BaseEstimator
+from qdk.training.base import BaseTrainer
 
 
-class Word2VecTrainingComponent(TrainingComponent):
+class Word2VecTrainer(BaseTrainer):
     tags = {
         "kind": "word2vec",
     }
@@ -58,7 +56,7 @@ class Word2VecTrainingComponent(TrainingComponent):
         vector_size: int = 100,
         window: int = 5,
         min_count: int = 5,
-        negative: int = 5
+        negative: int = 5,
     ) -> Word2Vec:
         # Train the Word2Vec model
         word2vec_model = Word2Vec(
@@ -66,7 +64,7 @@ class Word2VecTrainingComponent(TrainingComponent):
             vector_size=vector_size,
             window=window,
             min_count=min_count,
-            negative=5,
+            negative=negative,
             workers=multiprocessing.cpu_count(),
         )
 
