@@ -2,14 +2,13 @@ from typing import List, Tuple, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Enum, EnumValue, Field, InputDefinition, OutputDefinition
-from qdk.dagster_types import DataFrameType
-from qdk.transform.base import TransformComponent
+from dagster import Enum, EnumValue, Field
+from qdk.transform.base import BaseTransformer
 
 import yake
 
 
-class YakeComponent(TransformComponent):
+class YakeTransformer(BaseTransformer):
     config_schema = {
         "text_columns": Field(
             list,
