@@ -1,14 +1,20 @@
-def clean_text(text: str) -> str:
+from typing import Optional
+
+
+def clean_text(text: Optional[str]) -> str:
     """Perform basic text cleaning
     1. Normalize special characters
     2. Remove special quotes
 
     Args:
-        text (str): The text you want to clean
+        text (Optional[str]): The text you want to clean
 
     Returns:
         str: The cleaned text
     """
+    if not text:
+        return ""
+
     text = text.replace("è", "e")
     text = text.replace("é", "e")
     text = text.replace("ê", "e")
